==> core-0.1.42.tgz: package/esm/models/Engine.js <==
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import { TreeNode } from './TreeNode';
import { Workbench } from './Workbench';
import { Cursor } from './Cusor';
import { GlobalDragSource } from './DragSource';
import { Keyboard } from './Keyboard';
import { Screen, ScreenType } from './Screen';
import { Event, uid } from '@designable/shared';
var Engine = (function (_super) {
    __extends(Engine, _super);
    function Engine(props) {
        var _this = _super.call(this, props) || this;
        _this.source = GlobalDragSource;
        _this.props = __assign(__assign({}, Engine.defaultProps), props);
        _this.init();
        _this.id = uid();
        return _this;
    }
    Engine.prototype.init = function () {
        this.workbench = new Workbench(this);
        this.screen = new Screen(this);
        this.cursor = new Cursor(this);
        this.keyboard = new Keyboard(this);
    };
    Engine.prototype.setCurrentTree = function (tree) {
        if (this.workbench.currentWorkspace) {
            this.workbench.currentWorkspace.operation.tree.from(tree);
        }
    };
    Engine.prototype.getCurrentTree = function () {
        var _a, _b, _c;
        return (_c = (_b = (_a = this.workbench) === null || _a === void 0 ? void 0 : _a.currentWorkspace) === null || _b === void 0 ? void 0 : _b.operation) === null || _c === void 0 ? void 0 : _c.tree;
    };
    Engine.prototype.getAllSelectedNodes = function () {
        var results = [];
        for (var i = 0; i < this.workbench.workspaces.length; i++) {
            var workspace = this.workbench.workspaces[i];
            results = results.concat(workspace.operation.getSelectedNodes());
        }
        return results;
    };
    Engine.prototype.findNodeById = function (id) {
        for (var i = 0; i < this.workbench.workspaces.length; i++) {
            var workspace = this.workbench.workspaces[i];
            var node = workspace.operation.tree.findById(id);
            if (node) {
                return node;
            }
        }
    };
    Engine.prototype.findSourceNodeById = function (id) {
        return this.source.tree.findById(id);
    };
    Engine.prototype.findDraggingNodes = function () {
        var results = [];
        this.workbench.eachWorkspace(function (workspace) {
            var _a;
            (_a = workspace.operation.viewportDragon.dragNodes) === null || _a === void 0 ? void 0 : _a.forEach(function (node) {
                if (!results.includes(node)) {
                    results.push(node);
                }
            });
        });
        return results;
    };
    Engine.prototype.createNode = function (node, parent) {
        return new TreeNode(node, parent);
    };
    Engine.prototype.mount = function () {
        this.attachEvents(window);
    };
    Engine.prototype.unmount = function () {
        this.destroy();
    };
    Engine.defaultProps = {
        shortcuts: [],
        effects: [],
        drivers: [],
        sourceIdAttrName: 'data-designer-source-id',
        nodeIdAttrName: 'data-designer-node-id',
        nodeHelpersIdAttrName: 'data-designer-node-helpers-id',
        outlineNodeIdAttrName: 'data-designer-outline-node-id',
        defaultScreenType: ScreenType.PC,
    };
    return Engine;
}(Event));
export { Engine };

==> core-0.4.14.tgz: package/esm/models/Engine.js <==
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import { TreeNode } from './TreeNode';
import { Workbench } from './Workbench';
import { Cursor } from './Cursor';
import { GlobalDragSource } from './DragSource';
import { Keyboard } from './Keyboard';
import { Screen, ScreenType } from './Screen';
import { Event, uid } from '@designable/shared';
var Engine = (function (_super) {
    __extends(Engine, _super);
    function Engine(props) {
        var _this = _super.call(this, props) || this;
        _this.source = GlobalDragSource;
        _this.props = __assign(__assign({}, Engine.defaultProps), props);
        _this.init();
        _this.id = uid();
        return _this;
    }
    Engine.prototype.init = function () {
        this.workbench = new Workbench(this);
        this.screen = new Screen(this);
        this.cursor = new Cursor(this);
        this.keyboard = new Keyboard(this);
    };
    Engine.prototype.setCurrentTree = function (tree) {
        if (this.workbench.currentWorkspace) {
            this.workbench.currentWorkspace.operation.tree.from(tree);
        }
    };
    Engine.prototype.getCurrentTree = function () {
        var _a, _b, _c;
        return (_c = (_b = (_a = this.workbench) === null || _a === void 0 ? void 0 : _a.currentWorkspace) === null || _b === void 0 ? void 0 : _b.operation) === null || _c === void 0 ? void 0 : _c.tree;
    };
    Engine.prototype.getAllSelectedNodes = function () {
        var results = [];
        for (var i = 0; i < this.workbench.workspaces.length; i++) {
            var workspace = this.workbench.workspaces[i];
            results = results.concat(workspace.operation.getSelectedNodes());
        }
        return results;
    };
    Engine.prototype.findNodeById = function (id) {
        for (var i = 0; i < this.workbench.workspaces.length; i++) {
            var workspace = this.workbench.workspaces[i];
            var node = workspace.operation.tree.findById(id);
            if (node) {
                return node;
            }
        }
    };
    Engine.prototype.findSourceNodeById = function (id) {
        return this.source.tree.findById(id);
    };
    Engine.prototype.findDraggingNodes = function () {
        var results = [];
        this.workbench.eachWorkspace(function (workspace) {
            var _a;
            (_a = workspace.operation.viewportDragon.dragNodes) === null || _a === void 0 ? void 0 : _a.forEach(function (node) {
                if (!results.includes(node)) {
                    results.push(node);
                }
            });
        });
        return results;
    };
    Engine.prototype.createNode = function (node, parent) {
        return new TreeNode(node, parent);
    };
    Engine.prototype.mount = function () {
        this.attachEvents(window);
    };
    Engine.prototype.unmount = function () {
        this.destroy();
    };
    Engine.defaultProps = {
        shortcuts: [],
        effects: [],
        drivers: [],
        sourceIdAttrName: 'data-designer-source-id',
        nodeIdAttrName: 'data-designer-node-id',
        nodeHelpersIdAttrName: 'data-designer-node-helpers-id',
        outlineNodeIdAttrName: 'data-designer-outline-node-id',
        defaultScreenType: ScreenType.PC,
    };
    return Engine;
}(Event));
export { Engine };
